# LLM vs. LLM

[![Latest Tag](https://img.shields.io/github/v/tag/dylanhogg/llmvsllm)](https://github.com/dylanhogg/llmvsllm/tags)
[![Build](https://github.com/dylanhogg/llmvsllm/workflows/build/badge.svg)](https://github.com/dylanhogg/llmvsllm/actions/workflows/python-poetry-app.yml)

LLM vs. LLM: Simulates a rap battle or debate between two Large Language Models (LLMs)

Currently a WIP.
